@@ -18,7 +18,7 @@ from .state_vector import StateVector, StateVectorEntry
 # Class Purpose:
 #   to allow an easier time to form sync interest and handle all states
 class StateTable:
-    MTU = 7300
+    NDN_MTU = 8800
     def __init__(self, mynid:Name) -> None:
         self.table, self.meta, self.parts, self.nidstr = StateVector(), MetaData(), [[0,0]], Name.to_str(mynid)
         self.meta.source = self.nidstr.encode()
@@ -66,7 +66,7 @@ class StateTable:
             mainlist.append(templist)
         self.parts = mainlist
     def getPartMaximum(self, part:int) -> int:
-        return self.MTU # optimize this part for each packet (including interest)
+        return (self.NDN_MTU - 1500) # optimize this part for each packet (including interest)
     def getPartCuts(self) -> list:
         return self.parts
     def getSeqno(self, nid:Name) -> Optional[int]:
