@@ -17,6 +17,4 @@ class SVSyncTlvTypes(Enum):
     META_NOPCKS   = 200
     VECTOR        = 201
     VECTOR_ENTRY  = 202
-    SEQNO         = 203
-    PLOT_ENTRY    = 204
-    PLOT          = 205
\ No newline at end of file
+    SEQNO         = 203
\ No newline at end of file
